@@ -222,15 +222,11 @@ class ExplainableMatrix( RuleVectorMatrix ):
 			aux_inf = rule[ a ]
 			if( ( rule[ a ] == 'NaN' ) or ( rule[ a ] < threshold ) ):
 				aux_inf = rule[ a ]
-				
-				if threshold != 0.0:
-					
-					eps =  pow( 10, - str( threshold )[ ::-1 ].find('.') ) # ??
-					if threshold > 0.0:	rule[ a ] = threshold + eps
-					else: rule[ a ] = threshold - eps
 
-				else:
-					rule[ a ] = 0.0000001e-38 # a = np.finfo(np.float32) # a >>> finfo(resolution=1e-06, min=-3.4028235e+38, max=3.4028235e+38, dtype=float32) # a,tiny >>> 1.1754944e-38
+				eps = 0.0000001e-38 # a = np.finfo(np.float32) # a >>> finfo(resolution=1e-06, min=-3.4028235e+38, max=3.4028235e+38, dtype=float32) # a,tiny >>> 1.1754944e-38
+
+				if threshold >= 0.0: rule[ a ] = threshold + eps
+				else: rule[ a ] = threshold - eps
 
 			self.__path_to_rule( skl_tree, tree_id, right_child, rule, rules_matrix )
 
