@@ -189,11 +189,11 @@ class RuleVectorMatrix():
 
 		if self.rules_matrix_ is None:
 
-			self.rules_matrix_ = ssp.lil_matrix( [ rule_vector ] )
+			self.rules_matrix_ = ssp.lil_matrix( [ rule_vector ], dtype = np.float64 )
 
 		else:
 
-			self.rules_matrix_ = ssp.vstack( [ self.rules_matrix_, rule_vector ], format = 'lil' ) # takes to much time to run ??
+			self.rules_matrix_ = ssp.vstack( [ self.rules_matrix_, rule_vector ], format = 'lil', dtype = np.float64 ) # takes to much time to run
 
 		self.n_rules_ += 1
 
@@ -209,7 +209,7 @@ class RuleVectorMatrix():
 
 	def _set_rules_matrix( self, rules_matrix ):
 
-		self.rules_matrix_ = ssp.lil_matrix( rules_matrix )
+		self.rules_matrix_ = ssp.lil_matrix( rules_matrix, dtype = np.float64 )
 		
 		self.n_rules_ = self.rules_matrix_.shape[ 0 ]
 
@@ -730,7 +730,7 @@ class RuleVectorMatrix():
 
 
 			if self._verbose > 0: print( 'loading rules_matrix_ ...' )
-			self.rules_matrix_ = ssp.lil_matrix( np.loadtxt( file + '.csv', delimiter = ';', skiprows = 15 ) )
+			self.rules_matrix_ = ssp.lil_matrix( np.loadtxt( file + '.csv', delimiter = ';', skiprows = 15, dtype = np.float64 ) )
 			if self._verbose > 0: print( 'rules_matrix_ loaded ', self.rules_matrix_.shape )
 
 
